---
name: Bug Report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

### Bug description

A clear and concise description of what the bug is.

### To Reproduce

Ideally, provide a minimal code example. If that's not possible, describe steps to reproduce the bug.

### Expected behavior

A clear and concise description of what you expected to happen.

### Screenshots/Error messages

If applicable, add screenshots to help explain your problem.

### System

 - OS: [e.g. Ubuntu 18.04]
 - Version [e.g. 0.0.1]
